@@ -103,6 +103,8 @@ namespace vcpkg
         // reads any remaining chunks of the file; used to implement read_to_end
         void read_to_end_suffix(
             std::string& output, std::error_code& ec, char* buffer, size_t buffer_size, size_t last_read);
+        uint64_t size(LineInfo li) const;
+        uint64_t size(std::error_code& ec) const;
     };
 
     struct WriteFilePointer : FilePointer
@@ -334,6 +336,8 @@ namespace vcpkg
 
         virtual bool last_write_time(DiagnosticContext& context, const Path& target, int64_t new_time) const = 0;
 
+        virtual bool set_executable(DiagnosticContext& context, const Path& target) const = 0;
+
         using ReadOnlyFilesystem::current_path;
         virtual void current_path(const Path& new_current_path, std::error_code&) const = 0;
         void current_path(const Path& new_current_path, LineInfo li) const;
