@@ -3,7 +3,5 @@
 namespace vcpkg
 {
     struct SanitizedUrl;
-    struct SplitUrlView;
     struct AssetCachingSettings;
-    struct CurlProgressData;
 }
