@@ -22,13 +22,13 @@ namespace vcpkg::CMakeVars
     {
         virtual ~CMakeVarProvider() = default;
 
-        virtual Optional<const CMakeVars&> get_generic_triplet_vars(Triplet triplet) const = 0;
+        virtual const CMakeVars* get_generic_triplet_vars(Triplet triplet) const = 0;
 
-        virtual Optional<const CMakeVars&> get_dep_info_vars(const PackageSpec& spec) const = 0;
+        virtual const CMakeVars* get_dep_info_vars(const PackageSpec& spec) const = 0;
 
         const CMakeVars& get_or_load_dep_info_vars(const PackageSpec& spec, Triplet host_triplet) const;
 
-        virtual Optional<const CMakeVars&> get_tag_vars(const PackageSpec& spec) const = 0;
+        virtual const CMakeVars* get_tag_vars(const PackageSpec& spec) const = 0;
 
         virtual void load_generic_triplet_vars(Triplet triplet) const = 0;
 
@@ -36,7 +36,7 @@ namespace vcpkg::CMakeVars
 
         virtual void load_tag_vars(View<FullPackageSpec> specs, Triplet host_triplet) const = 0;
 
-        void load_tag_vars(const ActionPlan& action_plan, Triplet host_triplet) const;
+        void load_tag_vars(const std::vector<InstallPlanAction>& install_actions, Triplet host_triplet) const;
     };
 
     std::unique_ptr<CMakeVarProvider> make_triplet_cmake_var_provider(const VcpkgPaths& paths);
