@@ -22,42 +22,41 @@ namespace vcpkg
 {
     struct SpecSummary
     {
-        explicit SpecSummary(const InstallPlanAction& action);
-        explicit SpecSummary(const RemovePlanAction& action);
+        explicit SpecSummary(ExtendedBuildResult&& build_result,
+                             ElapsedTime timing,
+                             std::chrono::system_clock::time_point start_time);
 
-        const BinaryParagraph* get_binary_paragraph() const;
-        const PackageSpec& get_spec() const { return m_spec; }
-        const std::string* package_abi() const
-        {
-            if (m_install_action)
-            {
-                return m_install_action->package_abi();
-            }
-
-            return nullptr;
-        }
-        const std::string& package_abi_or_exit(LineInfo li) const
-        {
-            auto pabi = package_abi();
-            if (!pabi)
-            {
-                Checks::unreachable(li);
-            }
-
-            return *pabi;
-        }
-        bool is_user_requested_install() const;
-        Optional<ExtendedBuildResult> build_result;
+        ExtendedBuildResult build_result;
         vcpkg::ElapsedTime timing;
         std::chrono::system_clock::time_point start_time;
-        const InstallPlanAction* get_maybe_install_plan_action() const { return m_install_action; }
 
         std::string to_string() const;
         void to_string(std::string& out_str) const;
+    };
+
+    struct InstallSpecSummary : SpecSummary
+    {
+        explicit InstallSpecSummary(ExtendedBuildResult&& build_result,
+                                    const InternalFeatureSet& feature_list,
+                                    const Version& version,
+                                    RequestType request_type,
+                                    ElapsedTime timing,
+                                    std::chrono::system_clock::time_point start_time,
+                                    StringView package_abi,
+                                    const CompilerInfo* maybe_compiler_info);
+
+        const std::string& package_abi() const noexcept { return m_package_abi; }
+        const InternalFeatureSet& feature_list() const noexcept { return m_feature_list; }
+        const Version& version() const noexcept { return m_version; }
+        bool is_user_requested_install() const noexcept { return m_request_type == RequestType::USER_REQUESTED; }
+        const CompilerInfo* maybe_compiler_info() const noexcept { return m_compiler_info; }
 
     private:
-        const InstallPlanAction* m_install_action;
-        PackageSpec m_spec;
+        std::string m_package_abi;
+        InternalFeatureSet m_feature_list;
+        Version m_version;
+        RequestType m_request_type;
+        const CompilerInfo* m_compiler_info;
     };
 
     struct LicenseReport
@@ -69,7 +68,9 @@ namespace vcpkg
 
     struct InstallSummary
     {
-        std::vector<SpecSummary> results;
+        std::vector<SpecSummary> removed_results;
+        std::vector<InstallSpecSummary> already_installed_results;
+        std::vector<InstallSpecSummary> install_results;
         ElapsedTime elapsed;
         LicenseReport license_report;
         bool failed = false;
