@@ -679,11 +679,14 @@ namespace vcpkg
                 args.asset_sources_template_env.emplace(as_sv.data(), as_sv.size());
             }
 
-            if (obj.get(JsonIdVcpkgDisableMetrics))
-            {
-                args.disable_metrics = true;
-            }
+            // Metrics are intended to capture one user intended call to vcpkg, and vcpkg-in-vcpkg
+            // cases like x-download should not count as multiple uses.
+            //
+            // This also avoids the poison value set below crashing on platforms that use
+            // z-upload-metrics causing z-upload-metrics to crash.
+            args.disable_metrics = true;
 
+            // In vcpkg-in-vcpkg cases the lock is held by the outer vcpkg already.
             args.do_not_take_lock = true;
 
             // Setting the recursive data to 'poison' prevents more than one level of recursion because
@@ -714,11 +717,6 @@ namespace vcpkg
                 obj.insert(JsonIdVcpkgAssetSources, Json::Value::string(*ast));
             }
 
-            if (args.disable_metrics)
-            {
-                obj.insert(JsonIdVcpkgDisableMetrics, Json::Value::boolean(true));
-            }
-
             set_environment_variable(EnvironmentVariableXVcpkgRecursiveData,
                                      Json::stringify(obj, Json::JsonStyle::with_spaces(0)));
         }
